# Kiln AI Server

[![PyPI - Version](https://img.shields.io/pypi/v/kiln-server.svg)](https://pypi.org/project/kiln-server)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kiln-server.svg)](https://pypi.org/project/kiln-server)

---

## About

The Kiln AI Server is a Python library that provides a REST API server for the Kiln AI datamodel.

See our [website](https://kiln-ai.com) for more information.

## Table of Contents

- [Installation](#installation)

## Installation

```console
pip install kiln_server
```
